Author: guixl
Date: Tue May 18 13:42:16 2010
New Revision: 945649
URL: http://svn.apache.org/viewvc?rev=945649&view=rev
Log:
change source code package org.apache.commons.scxml to org.apache.commons.scxml.modeling
Added:
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Anchor.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Anchor.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Assign.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Assign.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Cancel.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Cancel.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Content.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Content.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Data.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Data.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/DataModel.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/DataModel.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Donedata.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Donedata.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Else.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Else.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ElseIf.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ElseIf.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExecutableContent.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExecutableContent.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExtenExecContent.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExtenExecContent.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/FinalState.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/FinalState.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Finalize.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Finalize.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/HistoryState.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/HistoryState.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/If.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/If.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/InitialState.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/InitialState.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Invoke.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Invoke.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Log.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Log.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/NamedElement.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/NamedElement.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/OnEntry.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/OnEntry.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/OnExit.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/OnExit.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Parallel.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Parallel.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Param.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Param.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Raise.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Raise.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Script.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Script.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ScxmlFactory.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ScxmlFactory.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ScxmlPackage.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ScxmlPackage.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Send.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Send.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ServiceTemplate.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ServiceTemplate.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/State.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/State.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Translation.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Translation.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Validate.java
- copied, changed from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Validate.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/
- copied from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/impl/
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/util/
- copied from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/util/
Removed:
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Anchor.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Assign.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Cancel.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Content.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Data.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/DataModel.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Donedata.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Else.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ElseIf.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExecutableContent.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExtenExecContent.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/FinalState.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Finalize.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/HistoryState.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/If.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/InitialState.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Invoke.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Log.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/NamedElement.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/OnEntry.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/OnExit.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Parallel.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Param.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Raise.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Script.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ScxmlFactory.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ScxmlPackage.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Send.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ServiceTemplate.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/State.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Translation.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Validate.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/impl/
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/util/
Modified:
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/.project
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/META-INF/MANIFEST.MF
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/plugin.xml
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/AnchorImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/AssignImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/CancelImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ContentImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/DataImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/DataModelImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/DonedataImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ElseIfImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ElseImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ExecutableContentImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ExtenExecContentImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/FinalStateImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/FinalizeImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/HistoryStateImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/IfImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/InitialStateImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/InvokeImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/LogImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/NamedElementImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/OnEntryImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/OnExitImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ParallelImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ParamImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/RaiseImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ScriptImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ScxmlFactoryImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ScxmlPackageImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/SendImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ServiceTemplateImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/StateImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/TranslationImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/impl/ValidateImpl.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/util/ScxmlAdapterFactory.java
commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/util/ScxmlSwitch.java
Modified: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/.project
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/.project?rev=945649&r1=945648&r2=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/.project (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/.project Tue May 18 13:42:16 2010
@@ -1,6 +1,6 @@
<?xml version="1.0" encoding="UTF-8"?>
<projectDescription>
- <name>org.apache.commons.scxml</name>
+ <name>org.apache.commons.scxml.modeling</name>
<comment></comment>
<projects>
</projects>
Modified: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/META-INF/MANIFEST.MF
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/META-INF/MANIFEST.MF?rev=945649&r1=945648&r2=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/META-INF/MANIFEST.MF (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/META-INF/MANIFEST.MF Tue May 18 13:42:16 2010
@@ -1,14 +1,14 @@
Manifest-Version: 1.0
Bundle-ManifestVersion: 2
Bundle-Name: %pluginName
-Bundle-SymbolicName: org.apache.commons.scxml;singleton:=true
+Bundle-SymbolicName: org.apache.commons.scxml.modeling;singleton:=true
Bundle-Version: 1.0.0
Bundle-ClassPath: .
Bundle-Vendor: %providerName
Bundle-Localization: plugin
-Export-Package: org.apache.commons.scxml,
- org.apache.commons.scxml.impl,
- org.apache.commons.scxml.util
+Export-Package: org.apache.commons.scxml.modeling,
+ org.apache.commons.scxml.modeling.impl,
+ org.apache.commons.scxml.modeling.util
Require-Bundle: org.eclipse.core.runtime,
org.eclipse.emf.ecore;visibility:=reexport
Eclipse-LazyStart: true
Modified: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/plugin.xml
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/plugin.xml?rev=945649&r1=945648&r2=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/plugin.xml (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/plugin.xml Tue May 18 13:42:16 2010
@@ -13,7 +13,7 @@
<extension point="org.eclipse.emf.ecore.generated_package">
<package
uri="org.apache.commons.scxml"
- class="org.apache.commons.scxml.ScxmlPackage"
+ class="org.apache.commons.scxml.modeling.ScxmlPackage"
genModel="model/sxcml.genmodel"/>
</extension>
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Anchor.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Anchor.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Anchor.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Anchor.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Anchor.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Anchor.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Anchor.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.ecore.EObject;
@@ -16,12 +16,12 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Anchor#getType <em>Type</em>}</li>
- * <li>{@link org.apache.commons.scxml.Anchor#getSnapshot <em>Snapshot</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Anchor#getType <em>Type</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Anchor#getSnapshot <em>Snapshot</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getAnchor()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAnchor()
* @model
* @generated
*/
@@ -36,14 +36,14 @@ public interface Anchor extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Type</em>' attribute.
* @see #setType(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getAnchor_Type()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAnchor_Type()
* @model
* @generated
*/
String getType();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Anchor#getType <em>Type</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Anchor#getType <em>Type</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Type</em>' attribute.
@@ -62,14 +62,14 @@ public interface Anchor extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Snapshot</em>' attribute.
* @see #setSnapshot(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getAnchor_Snapshot()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAnchor_Snapshot()
* @model
* @generated
*/
String getSnapshot();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Anchor#getSnapshot <em>Snapshot</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Anchor#getSnapshot <em>Snapshot</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Snapshot</em>' attribute.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Assign.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Assign.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Assign.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Assign.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Assign.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Assign.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Assign.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -15,13 +15,13 @@ package org.apache.commons.scxml;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Assign#getLocation <em>Location</em>}</li>
- * <li>{@link org.apache.commons.scxml.Assign#getDataid <em>Dataid</em>}</li>
- * <li>{@link org.apache.commons.scxml.Assign#getExpr <em>Expr</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Assign#getLocation <em>Location</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Assign#getDataid <em>Dataid</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Assign#getExpr <em>Expr</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getAssign()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAssign()
* @model
* @generated
*/
@@ -36,14 +36,14 @@ public interface Assign extends Executab
* <!-- end-user-doc -->
* @return the value of the '<em>Location</em>' attribute.
* @see #setLocation(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getAssign_Location()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAssign_Location()
* @model
* @generated
*/
String getLocation();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Assign#getLocation <em>Location</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Assign#getLocation <em>Location</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Location</em>' attribute.
@@ -62,14 +62,14 @@ public interface Assign extends Executab
* <!-- end-user-doc -->
* @return the value of the '<em>Dataid</em>' attribute.
* @see #setDataid(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getAssign_Dataid()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAssign_Dataid()
* @model
* @generated
*/
String getDataid();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Assign#getDataid <em>Dataid</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Assign#getDataid <em>Dataid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Dataid</em>' attribute.
@@ -88,14 +88,14 @@ public interface Assign extends Executab
* <!-- end-user-doc -->
* @return the value of the '<em>Expr</em>' attribute.
* @see #setExpr(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getAssign_Expr()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getAssign_Expr()
* @model
* @generated
*/
String getExpr();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Assign#getExpr <em>Expr</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Assign#getExpr <em>Expr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Expr</em>' attribute.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Cancel.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Cancel.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Cancel.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Cancel.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Cancel.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Cancel.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Cancel.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -15,12 +15,12 @@ package org.apache.commons.scxml;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Cancel#getSendid <em>Sendid</em>}</li>
- * <li>{@link org.apache.commons.scxml.Cancel#getSendidexpr <em>Sendidexpr</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Cancel#getSendid <em>Sendid</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Cancel#getSendidexpr <em>Sendidexpr</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getCancel()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getCancel()
* @model
* @generated
*/
@@ -35,14 +35,14 @@ public interface Cancel extends Executab
* <!-- end-user-doc -->
* @return the value of the '<em>Sendid</em>' attribute.
* @see #setSendid(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getCancel_Sendid()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getCancel_Sendid()
* @model
* @generated
*/
String getSendid();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Cancel#getSendid <em>Sendid</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Cancel#getSendid <em>Sendid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Sendid</em>' attribute.
@@ -61,14 +61,14 @@ public interface Cancel extends Executab
* <!-- end-user-doc -->
* @return the value of the '<em>Sendidexpr</em>' attribute.
* @see #setSendidexpr(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getCancel_Sendidexpr()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getCancel_Sendidexpr()
* @model
* @generated
*/
String getSendidexpr();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Cancel#getSendidexpr <em>Sendidexpr</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Cancel#getSendidexpr <em>Sendidexpr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Sendidexpr</em>' attribute.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Content.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Content.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Content.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Content.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Content.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Content.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Content.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.common.util.EList;
@@ -18,18 +18,18 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Content#getContent <em>Content</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Content#getContent <em>Content</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getContent()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getContent()
* @model
* @generated
*/
public interface Content extends EObject {
/**
* Returns the value of the '<em><b>Content</b></em>' containment reference list.
- * The list contents are of type {@link org.apache.commons.scxml.Content}.
+ * The list contents are of type {@link org.apache.commons.scxml.modeling.Content}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Content</em>' containment reference list isn't clear,
@@ -37,7 +37,7 @@ public interface Content extends EObject
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Content</em>' containment reference list.
- * @see org.apache.commons.scxml.ScxmlPackage#getContent_Content()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getContent_Content()
* @model type="org.apache.commons.scxml.Content" containment="true"
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Data.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Data.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Data.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Data.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Data.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Data.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Data.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.ecore.EObject;
@@ -16,14 +16,14 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Data#getId <em>Id</em>}</li>
- * <li>{@link org.apache.commons.scxml.Data#getSrc <em>Src</em>}</li>
- * <li>{@link org.apache.commons.scxml.Data#getExpr <em>Expr</em>}</li>
- * <li>{@link org.apache.commons.scxml.Data#getContent <em>Content</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Data#getId <em>Id</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Data#getSrc <em>Src</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Data#getExpr <em>Expr</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Data#getContent <em>Content</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getData()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getData()
* @model
* @generated
*/
@@ -38,14 +38,14 @@ public interface Data extends EObject {
* <!-- end-user-doc -->
* @return the value of the '<em>Id</em>' attribute.
* @see #setId(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getData_Id()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getData_Id()
* @model
* @generated
*/
String getId();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Data#getId <em>Id</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Data#getId <em>Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Id</em>' attribute.
@@ -64,14 +64,14 @@ public interface Data extends EObject {
* <!-- end-user-doc -->
* @return the value of the '<em>Src</em>' attribute.
* @see #setSrc(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getData_Src()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getData_Src()
* @model
* @generated
*/
String getSrc();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Data#getSrc <em>Src</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Data#getSrc <em>Src</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Src</em>' attribute.
@@ -90,14 +90,14 @@ public interface Data extends EObject {
* <!-- end-user-doc -->
* @return the value of the '<em>Expr</em>' attribute.
* @see #setExpr(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getData_Expr()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getData_Expr()
* @model
* @generated
*/
String getExpr();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Data#getExpr <em>Expr</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Data#getExpr <em>Expr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Expr</em>' attribute.
@@ -116,14 +116,14 @@ public interface Data extends EObject {
* <!-- end-user-doc -->
* @return the value of the '<em>Content</em>' containment reference.
* @see #setContent(Content)
- * @see org.apache.commons.scxml.ScxmlPackage#getData_Content()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getData_Content()
* @model containment="true"
* @generated
*/
Content getContent();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Data#getContent <em>Content</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Data#getContent <em>Content</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Content</em>' containment reference.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/DataModel.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/DataModel.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/DataModel.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/DataModel.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/DataModel.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/DataModel.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/DataModel.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.common.util.EList;
@@ -18,12 +18,12 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.DataModel#getSchema <em>Schema</em>}</li>
- * <li>{@link org.apache.commons.scxml.DataModel#getData <em>Data</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.DataModel#getSchema <em>Schema</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.DataModel#getData <em>Data</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getDataModel()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getDataModel()
* @model
* @generated
*/
@@ -38,14 +38,14 @@ public interface DataModel extends EObje
* <!-- end-user-doc -->
* @return the value of the '<em>Schema</em>' attribute.
* @see #setSchema(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getDataModel_Schema()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getDataModel_Schema()
* @model
* @generated
*/
String getSchema();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.DataModel#getSchema <em>Schema</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.DataModel#getSchema <em>Schema</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Schema</em>' attribute.
@@ -56,7 +56,7 @@ public interface DataModel extends EObje
/**
* Returns the value of the '<em><b>Data</b></em>' containment reference list.
- * The list contents are of type {@link org.apache.commons.scxml.Data}.
+ * The list contents are of type {@link org.apache.commons.scxml.modeling.Data}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Data</em>' containment reference list isn't clear,
@@ -64,7 +64,7 @@ public interface DataModel extends EObje
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Data</em>' containment reference list.
- * @see org.apache.commons.scxml.ScxmlPackage#getDataModel_Data()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getDataModel_Data()
* @model type="org.apache.commons.scxml.Data" containment="true"
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Donedata.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Donedata.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Donedata.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Donedata.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Donedata.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Donedata.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Donedata.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.common.util.EList;
@@ -18,12 +18,12 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Donedata#getContent <em>Content</em>}</li>
- * <li>{@link org.apache.commons.scxml.Donedata#getParam <em>Param</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Donedata#getContent <em>Content</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Donedata#getParam <em>Param</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getDonedata()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getDonedata()
* @model
* @generated
*/
@@ -38,14 +38,14 @@ public interface Donedata extends EObjec
* <!-- end-user-doc -->
* @return the value of the '<em>Content</em>' containment reference.
* @see #setContent(Content)
- * @see org.apache.commons.scxml.ScxmlPackage#getDonedata_Content()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getDonedata_Content()
* @model containment="true"
* @generated
*/
Content getContent();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Donedata#getContent <em>Content</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Donedata#getContent <em>Content</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Content</em>' containment reference.
@@ -56,7 +56,7 @@ public interface Donedata extends EObjec
/**
* Returns the value of the '<em><b>Param</b></em>' containment reference list.
- * The list contents are of type {@link org.apache.commons.scxml.Param}.
+ * The list contents are of type {@link org.apache.commons.scxml.modeling.Param}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Param</em>' containment reference list isn't clear,
@@ -64,7 +64,7 @@ public interface Donedata extends EObjec
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Param</em>' containment reference list.
- * @see org.apache.commons.scxml.ScxmlPackage#getDonedata_Param()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getDonedata_Param()
* @model type="org.apache.commons.scxml.Param" containment="true"
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Else.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Else.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Else.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Else.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Else.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Else.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Else.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -13,7 +13,7 @@ package org.apache.commons.scxml;
* <!-- end-user-doc -->
*
*
- * @see org.apache.commons.scxml.ScxmlPackage#getElse()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getElse()
* @model
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ElseIf.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ElseIf.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ElseIf.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ElseIf.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ElseIf.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ElseIf.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ElseIf.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -15,11 +15,11 @@ package org.apache.commons.scxml;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.ElseIf#getCond <em>Cond</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.ElseIf#getCond <em>Cond</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getElseIf()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getElseIf()
* @model
* @generated
*/
@@ -34,14 +34,14 @@ public interface ElseIf extends Executab
* <!-- end-user-doc -->
* @return the value of the '<em>Cond</em>' attribute.
* @see #setCond(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getElseIf_Cond()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getElseIf_Cond()
* @model
* @generated
*/
String getCond();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.ElseIf#getCond <em>Cond</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.ElseIf#getCond <em>Cond</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Cond</em>' attribute.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExecutableContent.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExecutableContent.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExecutableContent.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExecutableContent.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExecutableContent.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExecutableContent.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExecutableContent.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.ecore.EObject;
@@ -14,7 +14,7 @@ import org.eclipse.emf.ecore.EObject;
* <!-- end-user-doc -->
*
*
- * @see org.apache.commons.scxml.ScxmlPackage#getExecutableContent()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getExecutableContent()
* @model
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExtenExecContent.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExtenExecContent.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExtenExecContent.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExtenExecContent.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExtenExecContent.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/ExtenExecContent.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/ExtenExecContent.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -13,7 +13,7 @@ package org.apache.commons.scxml;
* <!-- end-user-doc -->
*
*
- * @see org.apache.commons.scxml.ScxmlPackage#getExtenExecContent()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getExtenExecContent()
* @model
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/FinalState.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/FinalState.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/FinalState.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/FinalState.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/FinalState.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/FinalState.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/FinalState.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -15,14 +15,14 @@ package org.apache.commons.scxml;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.FinalState#getId <em>Id</em>}</li>
- * <li>{@link org.apache.commons.scxml.FinalState#getOnEntry <em>On Entry</em>}</li>
- * <li>{@link org.apache.commons.scxml.FinalState#getOnExit <em>On Exit</em>}</li>
- * <li>{@link org.apache.commons.scxml.FinalState#getDonedata <em>Donedata</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.FinalState#getId <em>Id</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.FinalState#getOnEntry <em>On Entry</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.FinalState#getOnExit <em>On Exit</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.FinalState#getDonedata <em>Donedata</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalState()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalState()
* @model
* @generated
*/
@@ -37,14 +37,14 @@ public interface FinalState extends Name
* <!-- end-user-doc -->
* @return the value of the '<em>Id</em>' attribute.
* @see #setId(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalState_Id()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalState_Id()
* @model
* @generated
*/
String getId();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.FinalState#getId <em>Id</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.FinalState#getId <em>Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Id</em>' attribute.
@@ -63,14 +63,14 @@ public interface FinalState extends Name
* <!-- end-user-doc -->
* @return the value of the '<em>On Entry</em>' containment reference.
* @see #setOnEntry(OnEntry)
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalState_OnEntry()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalState_OnEntry()
* @model containment="true"
* @generated
*/
OnEntry getOnEntry();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.FinalState#getOnEntry <em>On Entry</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.FinalState#getOnEntry <em>On Entry</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>On Entry</em>' containment reference.
@@ -89,14 +89,14 @@ public interface FinalState extends Name
* <!-- end-user-doc -->
* @return the value of the '<em>On Exit</em>' containment reference.
* @see #setOnExit(OnExit)
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalState_OnExit()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalState_OnExit()
* @model containment="true"
* @generated
*/
OnExit getOnExit();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.FinalState#getOnExit <em>On Exit</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.FinalState#getOnExit <em>On Exit</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>On Exit</em>' containment reference.
@@ -115,14 +115,14 @@ public interface FinalState extends Name
* <!-- end-user-doc -->
* @return the value of the '<em>Donedata</em>' containment reference.
* @see #setDonedata(Donedata)
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalState_Donedata()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalState_Donedata()
* @model containment="true"
* @generated
*/
Donedata getDonedata();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.FinalState#getDonedata <em>Donedata</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.FinalState#getDonedata <em>Donedata</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Donedata</em>' containment reference.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Finalize.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Finalize.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Finalize.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Finalize.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Finalize.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Finalize.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Finalize.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.common.util.EList;
@@ -18,18 +18,18 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Finalize#getExecutableContent <em>Executable Content</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Finalize#getExecutableContent <em>Executable Content</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalize()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalize()
* @model
* @generated
*/
public interface Finalize extends EObject {
/**
* Returns the value of the '<em><b>Executable Content</b></em>' containment reference list.
- * The list contents are of type {@link org.apache.commons.scxml.ExecutableContent}.
+ * The list contents are of type {@link org.apache.commons.scxml.modeling.ExecutableContent}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Executable Content</em>' containment reference list isn't clear,
@@ -37,7 +37,7 @@ public interface Finalize extends EObjec
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Executable Content</em>' containment reference list.
- * @see org.apache.commons.scxml.ScxmlPackage#getFinalize_ExecutableContent()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getFinalize_ExecutableContent()
* @model type="org.apache.commons.scxml.ExecutableContent" containment="true"
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/HistoryState.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/HistoryState.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/HistoryState.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/HistoryState.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/HistoryState.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/HistoryState.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/HistoryState.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -15,12 +15,12 @@ package org.apache.commons.scxml;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.HistoryState#getId <em>Id</em>}</li>
- * <li>{@link org.apache.commons.scxml.HistoryState#getType <em>Type</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.HistoryState#getId <em>Id</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.HistoryState#getType <em>Type</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getHistoryState()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getHistoryState()
* @model
* @generated
*/
@@ -35,14 +35,14 @@ public interface HistoryState extends Na
* <!-- end-user-doc -->
* @return the value of the '<em>Id</em>' attribute.
* @see #setId(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getHistoryState_Id()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getHistoryState_Id()
* @model
* @generated
*/
String getId();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.HistoryState#getId <em>Id</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.HistoryState#getId <em>Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Id</em>' attribute.
@@ -61,14 +61,14 @@ public interface HistoryState extends Na
* <!-- end-user-doc -->
* @return the value of the '<em>Type</em>' attribute.
* @see #setType(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getHistoryState_Type()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getHistoryState_Type()
* @model
* @generated
*/
String getType();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.HistoryState#getType <em>Type</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.HistoryState#getType <em>Type</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Type</em>' attribute.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/If.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/If.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/If.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/If.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/If.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/If.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/If.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.common.util.EList;
@@ -16,13 +16,13 @@ import org.eclipse.emf.common.util.EList
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.If#getCond <em>Cond</em>}</li>
- * <li>{@link org.apache.commons.scxml.If#getElseif <em>Elseif</em>}</li>
- * <li>{@link org.apache.commons.scxml.If#getElse <em>Else</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.If#getCond <em>Cond</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.If#getElseif <em>Elseif</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.If#getElse <em>Else</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getIf()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getIf()
* @model
* @generated
*/
@@ -37,14 +37,14 @@ public interface If extends ExecutableCo
* <!-- end-user-doc -->
* @return the value of the '<em>Cond</em>' attribute.
* @see #setCond(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getIf_Cond()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getIf_Cond()
* @model
* @generated
*/
String getCond();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.If#getCond <em>Cond</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.If#getCond <em>Cond</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Cond</em>' attribute.
@@ -55,7 +55,7 @@ public interface If extends ExecutableCo
/**
* Returns the value of the '<em><b>Elseif</b></em>' containment reference list.
- * The list contents are of type {@link org.apache.commons.scxml.ElseIf}.
+ * The list contents are of type {@link org.apache.commons.scxml.modeling.ElseIf}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Elseif</em>' containment reference list isn't clear,
@@ -63,7 +63,7 @@ public interface If extends ExecutableCo
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Elseif</em>' containment reference list.
- * @see org.apache.commons.scxml.ScxmlPackage#getIf_Elseif()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getIf_Elseif()
* @model type="org.apache.commons.scxml.ElseIf" containment="true"
* @generated
*/
@@ -79,14 +79,14 @@ public interface If extends ExecutableCo
* <!-- end-user-doc -->
* @return the value of the '<em>Else</em>' containment reference.
* @see #setElse(Else)
- * @see org.apache.commons.scxml.ScxmlPackage#getIf_Else()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getIf_Else()
* @model containment="true"
* @generated
*/
Else getElse();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.If#getElse <em>Else</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.If#getElse <em>Else</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Else</em>' containment reference.
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/InitialState.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/InitialState.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/InitialState.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/InitialState.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/InitialState.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/InitialState.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/InitialState.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
/**
@@ -13,7 +13,7 @@ package org.apache.commons.scxml;
* <!-- end-user-doc -->
*
*
- * @see org.apache.commons.scxml.ScxmlPackage#getInitialState()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInitialState()
* @model
* @generated
*/
Copied: commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Invoke.java (from r945179, commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Invoke.java)
URL: http://svn.apache.org/viewvc/commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Invoke.java?p2=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Invoke.java&p1=commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Invoke.java&r1=945179&r2=945649&rev=945649&view=diff
==============================================================================
--- commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/Invoke.java (original)
+++ commons/sandbox/gsoc/2010/scxml-eclipse/trunk/src/main/java/org.apache.commons.scxml/src/org/apache/commons/scxml/modeling/Invoke.java Tue May 18 13:42:16 2010
@@ -4,7 +4,7 @@
*
* $Id$
*/
-package org.apache.commons.scxml;
+package org.apache.commons.scxml.modeling;
import org.eclipse.emf.common.util.EList;
@@ -18,21 +18,21 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
* <li>{@link org.apache.commons.scxml.Invoke#getContent <em>Content</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getParam <em>Param</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getType <em>Type</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getTypeexpr <em>Typeexpr</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getSrc <em>Src</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getSrcexpr <em>Srcexpr</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getId <em>Id</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getIdlocation <em>Idlocation</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getNamelist <em>Namelist</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getAutoforward <em>Autoforward</em>}</li>
* <li>{@link org.apache.commons.scxml.Invoke#getFinalize <em>Finalize</em>}</li>
* </ul>
* </p>
*
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke()
* @model
* @generated
*/
@@ -47,14 +47,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Content</em>' containment reference.
* @see #setContent(Content)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Content()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Content()
* @model containment="true"
* @generated
*/
Content getContent();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getContent <em>Content</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Content</em>' containment reference.
@@ -65,7 +65,7 @@ public interface Invoke extends EObject
/**
* Returns the value of the '<em><b>Param</b></em>' containment reference list.
* The list contents are of type {@link org.apache.commons.scxml.Param}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Param</em>' containment reference list isn't clear,
@@ -73,7 +73,7 @@ public interface Invoke extends EObject
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Param</em>' containment reference list.
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Param()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Param()
* @model type="org.apache.commons.scxml.Param" containment="true"
* @generated
*/
@@ -89,14 +89,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Type</em>' attribute.
* @see #setType(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Type()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Type()
* @model
* @generated
*/
String getType();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getType <em>Type</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Type</em>' attribute.
@@ -115,14 +115,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Typeexpr</em>' attribute.
* @see #setTypeexpr(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Typeexpr()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Typeexpr()
* @model
* @generated
*/
String getTypeexpr();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getTypeexpr <em>Typeexpr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Typeexpr</em>' attribute.
@@ -141,14 +141,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Src</em>' attribute.
* @see #setSrc(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Src()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Src()
* @model
* @generated
*/
String getSrc();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getSrc <em>Src</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Src</em>' attribute.
@@ -167,14 +167,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Srcexpr</em>' attribute.
* @see #setSrcexpr(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Srcexpr()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Srcexpr()
* @model
* @generated
*/
String getSrcexpr();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getSrcexpr <em>Srcexpr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Srcexpr</em>' attribute.
@@ -193,14 +193,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Id</em>' attribute.
* @see #setId(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Id()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Id()
* @model
* @generated
*/
String getId();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getId <em>Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Id</em>' attribute.
@@ -219,14 +219,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Idlocation</em>' attribute.
* @see #setIdlocation(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Idlocation()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Idlocation()
* @model
* @generated
*/
String getIdlocation();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getIdlocation <em>Idlocation</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Idlocation</em>' attribute.
@@ -245,14 +245,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Namelist</em>' attribute.
* @see #setNamelist(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Namelist()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Namelist()
* @model
* @generated
*/
String getNamelist();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getNamelist <em>Namelist</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Namelist</em>' attribute.
@@ -271,14 +271,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Autoforward</em>' attribute.
* @see #setAutoforward(String)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Autoforward()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Autoforward()
* @model
* @generated
*/
String getAutoforward();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getAutoforward <em>Autoforward</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Autoforward</em>' attribute.
@@ -297,14 +297,14 @@ public interface Invoke extends EObject
* <!-- end-user-doc -->
* @return the value of the '<em>Finalize</em>' containment reference.
* @see #setFinalize(Finalize)
- * @see org.apache.commons.scxml.ScxmlPackage#getInvoke_Finalize()
+ * @see org.apache.commons.scxml.modeling.ScxmlPackage#getInvoke_Finalize()
* @model containment="true"
* @generated
*/
Finalize getFinalize();
/**
* Sets the value of the '{@link org.apache.commons.scxml.Invoke#getFinalize <em>Finalize</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Finalize</em>' containment reference.
@@ -18,21 +18,21 @@ import org.eclipse.emf.ecore.EObject;
* The following features are supported:
* <ul>
- * <li>{@link org.apache.commons.scxml.Invoke#getContent <em>Content</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getParam <em>Param</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getType <em>Type</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getTypeexpr <em>Typeexpr</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getSrc <em>Src</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getSrcexpr <em>Srcexpr</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getId <em>Id</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getIdlocation <em>Idlocation</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getNamelist <em>Namelist</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getAutoforward <em>Autoforward</em>}</li>
- * <li>{@link org.apache.commons.scxml.Invoke#getFinalize <em>Finalize</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getContent <em>Content</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getParam <em>Param</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getType <em>Type</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getTypeexpr <em>Typeexpr</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getSrc <em>Src</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getSrcexpr <em>Srcexpr</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getId <em>Id</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getIdlocation <em>Idlocation</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getNamelist <em>Namelist</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getAutoforward <em>Autoforward</em>}</li>
+ * <li>{@link org.apache.commons.scxml.modeling.Invoke#getFinalize <em>Finalize</em>}</li>
* </ul>
* </p>
@@ -47,14 +47,14 @@ public interface Invoke extends EObject
Content getContent();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getContent <em>Content</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getContent <em>Content</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -65,7 +65,7 @@ public interface Invoke extends EObject
/**
* Returns the value of the '<em><b>Param</b></em>' containment reference list.
- * The list contents are of type {@link org.apache.commons.scxml.Param}.
+ * The list contents are of type {@link org.apache.commons.scxml.modeling.Param}.
* <!-- begin-user-doc -->
* <p>
@@ -89,14 +89,14 @@ public interface Invoke extends EObject
String getType();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getType <em>Type</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getType <em>Type</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -115,14 +115,14 @@ public interface Invoke extends EObject
String getTypeexpr();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getTypeexpr <em>Typeexpr</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getTypeexpr <em>Typeexpr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -141,14 +141,14 @@ public interface Invoke extends EObject
String getSrc();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getSrc <em>Src</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getSrc <em>Src</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -167,14 +167,14 @@ public interface Invoke extends EObject
String getSrcexpr();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getSrcexpr <em>Srcexpr</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getSrcexpr <em>Srcexpr</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -193,14 +193,14 @@ public interface Invoke extends EObject
String getId();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getId <em>Id</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getId <em>Id</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -219,14 +219,14 @@ public interface Invoke extends EObject
String getIdlocation();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getIdlocation <em>Idlocation</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getIdlocation <em>Idlocation</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -245,14 +245,14 @@ public interface Invoke extends EObject
String getNamelist();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getNamelist <em>Namelist</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getNamelist <em>Namelist</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -271,14 +271,14 @@ public interface Invoke extends EObject
String getAutoforward();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getAutoforward <em>Autoforward</em>}' attribute.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getAutoforward <em>Autoforward</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -297,14 +297,14 @@ public interface Invoke extends EObject
Finalize getFinalize();
/**
- * Sets the value of the '{@link org.apache.commons.scxml.Invoke#getFinalize <em>Finalize</em>}' containment reference.
+ * Sets the value of the '{@link org.apache.commons.scxml.modeling.Invoke#getFinalize <em>Finalize</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
|